batch_chat_structured

batch_chat_structured(chat, prompts, path, data_model, wait=True)

Submit multiple structured data requests in a batch.

Parameters

Name Type Description Default
chat Chat Chat instance to use for the batch required
prompts list[ContentT] | list[list[ContentT]] List of prompts to process required
path Union[str, Path] Path to file (with .json extension) to store batch state required
data_model type[BaseModelT] Pydantic model class for structured responses required
wait bool If True, wait for batch to complete. If False, return None if incomplete. True

Return

List of structured data objects (or None for failed requests), or None if wait=False and incomplete.